git

package
v0.0.0-...-11684cc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 16, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LatestsGitVersionTag

func LatestsGitVersionTag(repo *ggit.Repository, branch bool, sufsep string) (semver.SemVer, error)

LatestsGitVersionTag returns the latest version tag from the repository's tags. If `branch` is true, will only look at version tags suffixed with the branch name. sufsep is the suffix separator.

Types

This section is empty.

Jump to