Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LatestsGitVersionTag ¶
LatestsGitVersionTag returns the latest version tag from the repository's tags. If `branch` is true, will only look at version tags suffixed with the branch name. sufsep is the suffix separator.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.